*12345678901234567890123456789012345678901234567890123456789012345678901234567890

capture log close
clear
clear matrix
set mem 500m
set more off

#delimit ;

*	************************************************************************ *;
* 	File-Name: torture_tvc_reg.do                                            *;
*	Date:  11/3/2009                                                         *;
*	Author: 	James Hollyer                                                *;
*	Purpose:   To run a Cox regression using time varying covariates as a 	 *;
*	robustness check of the intitial torture paper results.  			 *;	                                                 
*	Data Input: Hollyer_torture_tvc_4.dta  						 *;
*	************************************************************************ *;

*	************************************************************************ *;
*	The following will load the Hollyer_torture_tvc_4.dta database into Stata*;
*	************************************************************************ *;

use "c:\documents and settings\james\desktop\my dropbox\IPE 2\Collaboration w Peter\Submissions\QJPS\Accepted Version\Replication Materials\Hollyer_torture_tvc_4.dta";

*	************************************************************************ *;
*	The following sequence of steps will be used to create a variable        *;
*	indicating whether or not a given regime inherited signatory status from *;
*	a prior regime.										 *;
*	************************************************************************ *;

by obsid, sort: egen maxsign=max(cats);

sort obsid year;

gen inherit_signatory=.;

replace inherit_signatory=1 if maxsign[_n-1]==1 & leadid~=leadid[_n-1] & ccode==ccode[_n-1];

replace inherit_signatory=1 if inherit_signatory[_n-1]==1 & leadid==leadid[_n-1];

replace inherit_signatory=0 if inherit_signatory==.;

drop maxsign;

*	************************************************************************ *;
*	The current measure of CAT signing is a binary indicator that takes a 	 *;
*	value of 1 for every year after signing.  Replace this measure with an   *;
*	indicator that takes a value of 1 only in the year of signing.			 *;
*	************************************************************************ *;

sort leadid year;

gen cats_lag2 = .;
replace cats_lag2 = 1 if cats_lag==1 & cats_lag[_n-1]==0 & leadid==leadid[_n-1];
replace cats_lag2 = 0 if cats_lag2==. & cats_lag~=.;

*	************************************************************************ *;
*	The following will run a Cox proportional hazards regression using TVCs  *;
*	on the lagged signing of the CAT.							 *;
*	************************************************************************ *;

rename g growth;

rename level gdp_per_cap;

rename tort_ciri torture_ciri;

stcox  cats_lag2 torture acchead civilian inherit party resource growth gdp_per_cap 
cinc war population if inherit_signatory==0, cluster(ccode) nohr;

est2vec preferredmod, replace name(Hath);

stcox  cats_lag2 torture acchead civilian growth cinc war
 if inherit_signatory==0, cluster(ccode) nohr;
est2vec, addto(preferredmod) name(Hath2);

stcox cats_lag2  torture_ciri acchead party civilian inherit  resource growth 
gdp_per_cap cinc war population if inherit_signatory==0, cluster(ccode) nohr;

est2vec, addto(preferredmod) name(CIRI);

stcox  cats_lag2 torture_ciri acchead civilian  growth cinc war
 if inherit_signatory==0, cluster(ccode) nohr;
est2vec, addto(preferredmod) name(CIRI2);

*	************************************************************************ *;
*	The following will obtain the Schoenfeld residuals with the purpose of   *;
*	testing the proportional hazards assumption.							 *;
*	************************************************************************ *;

stcox  cats_lag2 torture acchead civilian party inherit resource growth gdp_per_cap 
cinc war population if inherit_signatory==0, cluster(ccode) schoenfeld(SchHath*) nohr;

estat phtest;

estat phtest, rank detail;

stcox  cats_lag2 torture_ciri acchead civilian party inherit  resource growth gdp_per_cap 
cinc war population if inherit_signatory==0, cluster(ccode) schoenfeld(SchCIRI*) nohr;

estat phtest;

estat phtest, rank detail;

*So the global proportional hazards assumption does not reject the;
*proportional hazards assumption in any model.;

stcox  cats_lag2 torture acchead civilian party inherit resource growth gdp_per_cap 
cinc war population if inherit_signatory==0, tvc(cinc war population) cluster(ccode) nohr;

stcox  cats_lag2 torture_ciri acchead civilian party inherit  resource growth gdp_per_cap 
cinc war population if inherit_signatory==0, tvc(cinc war population) cluster(ccode) nohr;

*So substantive results are unchanged adjusting for time-varying covariates.;

*	************************************************************************ *;	
*	The following will construct survival plots based on the regressions 	 *;
*	above.																	 *;
*	************************************************************************ *;	

stcox  cats_lag2 torture acchead civilian party inherit  resource growth gdp_per_cap 
cinc war population if inherit_signatory==0, cluster(ccode) nohr;

stcurve, hazard at1(cats_lag2=1) at2(cats_lag2=0) lcolor(gs1) graphregion(fcolor(white)) 
title(Cox Model Estimates: Hazard Function) subtitle(Hathaway Torture Control) 
yscale(range(0,.15)) xtitle(Years) ytitle(Hazard Rate) scheme(s1mono)
legend(label(1 Signatories) label(2 Non-Signatories));

*graph export "c:\documents and settings\james\desktop\my dropbox\ipe 2\collaboration w peter\hazard_plot_hath.png",
replace;

stcox cats_lag2 torture_ciri acchead civilian party inherit  resource growth 
gdp_per_cap cinc war population if inherit_signatory==0, cluster(ccode) nohr;

stcurve, hazard at1(cats_lag2=1) at2(cats_lag2=0)  lcolor(gs1) graphregion(fcolor(white)) 
title(Cox Model Estimates: Hazard Function) subtitle(CIRI Torture Control) 
yscale(range(0,.15)) xtitle(Years) ytitle(Hazard Rate)scheme(s1mono)
legend(label(1 Signatories) label(2 Non-Signatories));

*graph export "c:\documents and settings\james\desktop\my dropbox\ipe 2\collaboration w peter\hazard_plot_ciri.png",
replace;

*	************************************************************************ *;
*	The following will export the TVC table.						 *;
*	************************************************************************ *;

*est2tex preferredmod, preserve path("c:\documents and settings\james\desktop\my dropbox\ipe 2\collaboration w peter\") 
*mark(stars) dot replace;

