capture log close

clear
clear matrix
set mem 500m
set more off

#delimit ;

*	************************************************************************ *;
* 	File-Name: 08APSR_TortureAnalysis.do									 *;
*	Date:  02/04/10															 *;
*	Author: 	James Hollyer                                                *;
*	Purpose:   To run a preliminary analysis of the unrest data to look for  *;
*	an effect of CAT signings on torture levels.							 *;
*	Data Input: APSR_Unrest_data_final.dta									 *;
*	************************************************************************ *;

use "c:\documents and settings\james\desktop\my dropbox\ipe 2\collaboration w peter\submissions\QJPS\Accepted Version\Replication Materials\Unrest_data_final.dta";

*	************************************************************************ *;
*	The following will tsset the data.										 *;
*	************************************************************************ *;

tsset ccode year;
drop if reg==0;

*	************************************************************************ *;
*	The following will run the analysis on torture.  I will confine the 	 *;
*	analysis to time-series variation in signatory states - since this is    *;
*	consistent with model predictions.  Also, I since the matching algorithm *;
*	conditioned propensity scores on torture levels, it would be inappropiate*;
*	to adjust for propensity score weightings.								 *;
*	************************************************************************ *;

by ccode, sort: egen eversign=max(cats);

gen change_torture =.;
replace change_torture = torture-torture[_n-1] if ccode==ccode[_n-1];
*Since the data is ordinal, I recode this variable as {-1,0,1} indicating a;
*decrease, no change, and an increase, respectively.;

recode change_torture (-3=-1) (-2=-1) (-1=-1) (0=0) (1=1) (2=1) (3=1), gen(change_torture_rc);

gen change_tort_ciri =.;
replace change_tort_ciri=tort_ciri - tort_ciri[_n-1];
recode change_tort_ciri (-2=-1) (-1=-1) (0=0) (1=1) (2=1), gen(change_tort_ciri_rc);

oprobit change_torture L.change_cat change_gdp change_cap 
change_growth  change_openness t t2 t3 if eversign==1, cluster(ccode);

est2vec tortchange, replace name(SignatoriesHath);

oprobit change_torture L.change_cat t t2 t3 if eversign==1, cluster(ccode);

oprobit change_tort_ciri L.change_cat change_gdp change_cap 
change_growth  change_openness t t2 t3 if eversign==1, cluster(ccode);

est2vec, addto(tortchange) name(SignatoriesCiri);

oprobit change_tort_ciri L.change_cat change_gdp change_cap 
change_growth  change_openness t t2 t3 if eversign==1, cluster(ccode);

est2vec tortcirichange, replace name(SignatoriesCiri);

*The following will expand the analysis to all country-years;
*both eventual signatories and non-signatories.;

oprobit change_torture L.change_cat change_gdp change_cap 
change_growth  change_openness t t2 t3, cluster(ccode);

est2vec, addto(tortchange) name(AllHath);

oprobit change_torture L.change_cat t t2 t3, cluster(ccode);

oprobit change_tort_ciri L.change_cat change_gdp change_cap 
change_growth  change_openness t t2 t3, cluster(ccode);

est2vec, addto(tortchange) name(AllCIRI);

oprobit change_tort_ciri L.change_cat change_gdp change_cap 
change_growth  change_openness t t2 t3, cluster(ccode);

est2vec, addto(tortcirichange) name(AllCIRI);



*est2tex tortchange, preserve path("c:\documents and settings\james\desktop\my dropbox\ipe 2\collaboration w peter\submissions\QJPS\Accepted Version\Replication Materials\")
mark(stars) dot replace;

*est2tex tortcirichange, preserve path("c:\documents and settings\james\desktop\my dropbox\ipe 2\collaboration w peter\submissions\QJPS\Accepted Version\Replication Materials\")
mark(stars) dot replace;




