capture log close

clear
clear matrix
set mem 500m
set more off

#delimit ;

*	************************************************************************ *;
* 	File-Name: 03unrestMatch.do										 *;
*	Date:  01/25/10															 *;
*	Author: 	James Hollyer                                                *;
*	Purpose:   To prepare the domestic unrest country-year dataset for 		 *;
*	preprocessing using matching (according to the panel-matching techniques *;
*	from Simmons &?.  													 	 *;
*	Data Input: unrest_Data.dta										 *;
*	************************************************************************ *;

use "c:\documents and settings\james\desktop\my dropbox\ipe 2\collaboration w peter\submissions\QJPS\Accepted Version\Replication Materials\unrest_data.dta";


*	************************************************************************ *;
*	Here I want to collapse the data down by country, taking only pre-		 *;
*	treatment observations of those countries that ultimately signed the CAT.*;
*	I also want to drop all countries that were not autocracies at the time  *;
*	of CAT signing from the data.  The resultant country level data will be  *;
*	used to match observationally similar panels.							 *;
*	************************************************************************ *;


*The following will drop all countries that (a) were always democratic or (b);
*were autocratic at some point during the dataset, but signed the CAT as; 
*democracies.;

sort ccode year;

by ccode, sort: egen everaut=max(reg);

drop if everaut==0;
drop everaut;

sort ccode year;

gen demsign=.;
replace demsign=1 if reg==0 & cats==1 & cats[_n-1]==0 & ccode==ccode[_n-1];
replace demsign=0 if demsign==.; 
by ccode, sort: egen everdemsign=max(demsign);

drop if everdemsign==1;
drop demsign everdemsign;

*The following will drop all observations after 'treatment' ie after the;
*CAT is signed.;

sort ccode year;

drop if cats==1 & cats[_n-1] & ccode==ccode[_n-1]==1;

*The following will collapse the observations by country, keeping the treatment;
*variable (signing the CAT) and taking either the mean or the median value of;
*controls we're matching on, depending on which is most appropriate.;

collapse (mean) level g muslim population cinc tradegdp (median) reg inherit military
resource tort_ciri torture civilian (max) cats acchead war communist (first) countryname, 
by(ccode);

*The data needs to be rectangularized for MatchIt - therefore I drop all missing observations;
*on the variables of interest.;


drop if tort_ciri==.;
drop if torture==.;
drop if level==.;
drop if g==.;
drop if muslim==.;
drop if population==.;
drop if cinc==.;
drop if tradegdp==.;
drop if inherit==.;
drop if military==.;
drop if resource==.;
drop if acchead==.;
drop if war==.;
drop if communist==.;

save "c:\documents and settings\james\desktop\my dropbox\ipe 2\collaboration w peter\submissions\QJPS\Accepted Version\Replication Materials\For_Matching.dta",
replace;
