capture log close

clear
clear matrix
set mem 500m
set more off

#delimit ;

*	************************************************************************ *;
* 	File-Name: 05APSR_Construct.do											 *;
*	Date:  01/26/10															 *;
*	Author: 	James Hollyer                                                *;
*	Purpose:   To merge the weights created by the genetic matching in R with*;
*	the full dataset and to construct the variables of interest (first 		 *;
*	differences) for subsequent analysis.									 *;
*	Data Input: Matched.dta, APSR_Unrest_Data.dta							 *;
*	************************************************************************ *;

use "c:\documents and settings\james\desktop\my dropbox\ipe 2\Collaboration w Peter\Submissions\QJPS\Accepted Version\Replication Materials\Matched";

sort ccode;

save "c:\documents and settings\james\desktop\my dropbox\ipe 2\Collaboration w Peter\Submissions\QJPS\Accepted Version\Replication Materials\Matched",
replace;

use "c:\documents and settings\james\desktop\my dropbox\ipe 2\Collaboration w Peter\Submissions\QJPS\Accepted Version\Replication Materials\unrest_data.dta";

*The following will drop all countries that (a) were always democratic or (b);
*were autocratic at some point during the dataset, but signed the CAT as; 
*democracies.;

sort ccode year;

by ccode, sort: egen everaut=max(reg);

drop if everaut==0;
drop everaut;

sort ccode year;

gen demsign=.;
replace demsign=1 if reg==0 & cats==1 & cats[_n-1]==0 & ccode==ccode[_n-1];
replace demsign=0 if demsign==.; 
by ccode, sort: egen everdemsign=max(demsign);

drop if everdemsign==1;
drop demsign everdemsign;

sort ccode year;

merge m:1 ccode using "c:\documents and settings\james\desktop\my dropbox\ipe 2\Collaboration w Peter\Submissions\QJPS\Accepted Version\Replication Materials\Matched.dta";

drop _merge;

*Observations pruned by the matching process should be assigned a weight of;
*zero (they are simply excluded from the Matched.dta dataset.)  I assign these;
*weights here.;

replace weights=0 if weights==.;


*	************************************************************************ *;
*	The following will take first diffences of the dependent and explanatory *;
*	variables of interest.													 *;
*	************************************************************************ *;

sort ccode year;

gen change_assass=.;
replace change_assass=Assinations-Assinations[_n-1] if ccode==ccode[_n-1];
label variable change_assass "First Difference in Number of Assassinations by Country-Year";

gen change_strikes=.;
replace change_strikes=GenStrikes-GenStrikes[_n-1] if ccode==ccode[_n-1];
label variable change_strikes "First Difference in Number of General Strikes by Country-Year";

gen change_crises=.;
replace change_crises=GovCrises-GovCrises[_n-1] if ccode==ccode[_n-1];
label variable change_crises "First Difference in Number of Crises by Country-Year";

gen change_riots=.;
replace change_riots=Riots-Riots[_n-1] if ccode==ccode[_n-1];
label variable change_riots "First Difference in Number of Riots by Country-Year";

gen change_rev=.;
replace change_rev=Revolutions-Revolutions[_n-1] if ccode==ccode[_n-1];
label variable change_rev "First Difference in Number of Revoultions by Country-Year";

gen change_demos=.;
replace change_demos=AntiGovDem-AntiGovDem[_n-1] if ccode==ccode[_n-1];
label variable change_demos "First Differnce in Number of Anti-Government Demonstrations by Country-Year";

gen change_guer=.;
replace change_guer=Guerilla-Guerilla[_n-1] if ccode==ccode[_n-1];
label variable change_gue "First Difference in Number of Guerilla Movements by Country-Year";

gen change_cat=.;
replace change_cat=cats-cats[_n-1] if ccode==ccode[_n-1];
label variable change_cat "First Difference in CAT Signatory Status";

*The PRIO dataset only estimates the number of battledeaths (low/high estimate);
*if a civil war is ongoing.  Therefore - instances in which no war is coded -;
*these measures will be missing.  I recode these variables so that zero replaces;
*such missing values.;

replace bdeadlow=0 if bdeadlow==. & type~=1;
replace bdeadhigh=0 if bdeadhigh==. & type~=1;

gen change_bdeadlow=.;
replace change_bdeadlow=bdeadlow-bdeadlow[_n-1] if ccode==ccode[_n-1];
label variable change_bdeadlow "First Difference in the Low Estimate Number of Battle Deaths by Country-Year";

gen change_bdeadhigh=.;
replace change_bdeadhigh=bdeadhigh-bdeadhigh[_n-1] if ccode==ccode[_n-1];
label variable change_bdeadhigh "First Difference in the High Estimate Number of Battle Deaths by Country-Year";

gen change_growth=.;
replace change_growth=g-g[_n-1] if ccode==ccode[_n-1];
label variable change_growth "First Difference in the Growth Rate by Country Year";

gen change_pop=.;
replace change_pop=population-population[_n-1] if ccode==ccode[_n-1];
label variable change_pop "First Difference in the Population by Country-Year";

gen change_cap=.;
replace change_cap=cinc-cinc[_n-1] if ccode==ccode[_n-1];
label variable change_cap "First Difference in the Military Capabilities Index by Country-Year";

gen change_openness=.;
replace change_openness=tradegdp-tradegdp[_n-1] if ccode==ccode[_n-1];
label variable change_openness "First Difference in Trade as a Pct. of GDP by Country-Year";

gen change_gdp=.;
replace change_gdp = level - level[_n-1] if ccode==ccode[_n-1];
label variable change_gdp "First Difference in GDP per capita by Country-Year";

*	************************************************************************ *;
*	The following will generate a cubic time trend.							 *;
*	************************************************************************ *;

gen t=.;

replace t=year-1985;
label variable t "Time";

gen t2=.;
replace t2=t^2;
label variable t2 "Time Squared";

gen t3=.;
replace t3=t^3;
label variable t3 "Time Cubed";

save "c:\documents and settings\james\desktop\my dropbox\ipe 2\Collaboration w Peter\Submissions\QJPS\Accepted Version\Replication Materials\Unrest_data_final.dta",
replace;
