*12345678901234567890123456789012345678901234567890123456789012345678901234567890

capture log close
graph drop _all
clear
clear matrix
set mem 500m
set more off

#delimit ;

*	************************************************************************ *;
* 	File-Name: torture_magnitude.do                                          *;
*	Date:  11/18/2020                                                        *;
*	Author: 	James Hollyer                                                *;
*	Purpose:   To determine the magnitude of the difference between eventual *;
*	signers and never-signers in the level of torture applied. 			 	 *;	                                                 
*	Data Input: Hollyer_torture_tvc_4.dta  						 			 *;
*	************************************************************************ *;

use "c:\documents and settings\james\desktop\my dropbox\IPE 2\Collaboration w Peter\submissions\QJPS\Accepted Version\Replication Materials\Hollyer_torture_tvc_4.dta";

*	************************************************************************ *;
*	The following will drop years after signing from the dataset and will    *;
*	generate a variable equal to 1 if a leader was ever a signatory to the   *;
*	CAT.																	 *;
*	************************************************************************ *;

by leadid, sort: egen eversign=max(cats);

drop if year>=cats_year;

*	************************************************************************ *;
*	The following will estimate the difference between eventual signers and  *;
*	never signers in torture levels, using both ordered probit and linear    *;
*	models.																	 *;
*	************************************************************************ *;

oprobit  torture eversign, cluster(ccode);
estimates store Hath_probit;

oprobit  tort_ciri eversign, cluster(ccode);
estimates store CIRI_probit;

reg  torture eversign, cluster(ccode);
estimates store Hath_reg;

reg  tort_ciri eversign, cluster(ccode);
estimates store CIRI_reg;

*estout Hath_probit CIRI_probit Hath_reg CIRI_reg using 
"C:\Documents and Settings\James\Desktop\My Dropbox\IPE 2\Collaboration w Peter\submissions\QJPS\magnitude_est.tex",
cells(b(star fmt(3)) se(par fmt(3))) style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) replace;

*	************************************************************************ *;
*	The following will simulate the difference between a zero and a 1 on the *;
*	eversign variable on the predicted probabilities of torturing at 		 *;
*	different levels.														 *;
*	************************************************************************ *;

estsimp oprobit torture eversign, cluster(ccode);

setx (eversign) 0;

simqi, genpr(non_sig_torture1 non_sig_torture2 non_sig_torture3 non_sig_torture4 non_sig_torture5);

setx (eversign) 1;

simqi, genpr(sig_torture1 sig_torture2 sig_torture3 sig_torture4 sig_torture5);

gen diff_torture1=sig_torture1 - non_sig_torture1;
gen diff_torture2=sig_torture2 - non_sig_torture2;
gen diff_torture3=sig_torture3 - non_sig_torture3;
gen diff_torture4=sig_torture4 - non_sig_torture4;
gen diff_torture5=sig_torture5 - non_sig_torture5;

gen mean_torture_diff=.;
gen ub_torture_diff=.;
gen lb_torture_diff=.;

forvalues i=1(1)5{;
	sum diff_torture`i';
	replace mean_torture_diff = r(mean) if _n==`i';
	_pctile diff_torture`i', p(2.5 97.5);
	replace ub_torture_diff=r(r2) if _n==`i';
	replace lb_torture_diff=r(r1) if _n==`i';
};

drop b*;

estsimp oprobit tort_ciri eversign, cluster(ccode);

setx (eversign) 0;

simqi, genpr(non_sig_tort1 non_sig_tort2 non_sig_tort3);

setx (eversign) 1;

simqi, genpr(sig_tort1 sig_tort2 sig_tort3);

gen diff_tort1=sig_tort1 - non_sig_tort1;
gen diff_tort2=sig_tort2 - non_sig_tort2;
gen diff_tort3=sig_tort3 - non_sig_tort3;

gen mean_tort_diff=.;
gen ub_tort_diff=.;
gen lb_tort_diff=.;

forvalues i=1(1)3{;
	sum diff_tort`i';
	replace mean_tort_diff = r(mean) if _n==`i';
	_pctile diff_tort`i', p(2.5 97.5);
	replace ub_tort_diff=r(r2) if _n==`i';
	replace lb_tort_diff=r(r1) if _n==`i';
};

gen torture_meas_num=_n if _n<=5;

graph twoway (rcap ub_torture_diff lb_torture_diff torture_meas_num) 
(scatter mean_torture_diff torture_meas_num, graphregion(fcolor(white))
title(Difference in Predicted Probabilities) subtitle(Hathaway Torture Score)
xtitle(Torture (Hathaway)) ytitle(Diff. in Predicted Probabilities) legend(off)
name(Hathaway) scheme(s2mono));

graph twoway (rcap ub_tort_diff lb_tort_diff torture_meas_num if torture_meas_num<=3) 
(scatter mean_tort_diff torture_meas_num if torture_meas_num<=3, graphregion(fcolor(white))
title(Difference in Predicted Probabilities) subtitle(CIRI Torture Score)
xtitle(Torture (CIRI)) ytitle(Diff. in Predicted Probabilities) legend(off)
xlabel(1(1)3) name(CIRI) scheme(s2mono));

graph combine Hathaway CIRI, ycommon graphregion(fcolor(white)) 
title(Eventual Signatories versus Non-Signatories) subtitle(Predicted Probability of Torture)
scheme(s2mono);

*graph export "c:\documents and settings\james\desktop\my dropbox\ipe 2\collaboration w peter\submissions\qjps\qjps response.png",
replace;
